class ProxyConfig {
  final String name;
  final String type;
  final String server;
  final int port;
  final String password;
  final bool udp;
  // vless
  final String? flow;
  final String? servername;
  final bool? tls;
  final Reality? realityOpts;
  // V2Ray/VLESS特定属性
  final String? uuid;
  final int? alterId;
  // Shadowsocks特定属性
  final String? cipher;
  ProxyConfig({
    required this.name,
    required this.type,
    required this.server,
    required this.port,
    required this.password,
    required this.udp,
    this.flow,
    this.servername,
    this.tls,
    this.realityOpts, // 新增字段
    this.uuid,
    this.alterId,
    this.cipher
  });

  // 更新解析方法
  factory ProxyConfig.fromMap(Map<String, dynamic> map) {
    return ProxyConfig(
      name: map['name'],
      type: map['type'],
      server: map['server'],
      port: map['port'],
      password: map['password'],
      udp: map['udp'],
      flow: map['flow'],
      servername: map['servername'],
      tls: map['tls'],
      realityOpts: map['reality-opts'] != null ? Reality.fromMap(map['reality-opts']) : null,
      uuid: map['uuid'],
      alterId: map['alterId'],
      cipher:map['cipher']
    );
  }

  // 更新 JSON 序列化方法
  Map<String, dynamic> toJson() {
    return {
      'name': name,
      'type': type,
      'server': server,
      'port': port,
      'password': password,
      'udp': udp,
      'flow': flow,
      'servername': servername,
      'tls': tls,
      'reality-opts': realityOpts?.toJson(),
      'uuid': uuid,
      'alterId': alterId,
      'cipher' : cipher
    };
  }

  String toYaml() {
    return '''
- name: $name
  type: $type
  server: $server
  port: $port
  password: $password
  udp: $udp
  flow: $flow
  servername: $servername
  tls: $tls ?? ''
  ${realityOpts?.toYaml() ?? ''}
  uuid: $uuid ?? ''
  alterId: $alterId ?? ''
  cipher : $cipher ?? ''
''';
  }
}
class Reality {
  final String? publicKey;

  Reality({this.publicKey});

  factory Reality.fromMap(Map<String, dynamic> map) {
    return Reality(
      publicKey: map['public-key'] as String?,
    );
  }

  Map<String, dynamic> toJson() {
    return {
      'public-key': publicKey,
    };
  }

  String toYaml() {
    return publicKey != null ? 'reality-opts:\n  public-key: $publicKey' : '';
  }
}